#include "stealth.ih"

void Stealth::terminate()
{
    timestamp("terminates");
}
